remove TRUE converted to class character from findings.
tidy_findings(findings)a character vector without any element reading "TRUE" or NULL.
a character vector with possibly some elements reading "TRUE" or a vector of TRUES.
check_directory, check_file,
check_functions_in_file and
check_function_layout all collect tryCatch to collect either
TRUE for a check passed or a character holding a conditions message. This
function deletes the TRUES.